@@ -4,6 +4,11 @@ Compartmentalizes settings into multiple sub-settings files, including 'database
 # DJANGO CORE SETTINGS
 from backstage.settings.django_settings import *
 
+# SERVER SETTINGS (nginx, uwsgi, etc)
+UWSGI_VASSALS = '/etc/uwsgi-emperor/vassals/'
+NGINX_BASE = '/etc/nginx/'
+
+
 # MEZZANINE SETTINGS
 try:
     from local.local_settings import Mezzanine
