@@ -5,6 +5,6 @@ register = template.Library()
 
 # settings value
 @register.simple_tag
-def settings(name):
+def csettings(name):
     """ provides for the inclusion of setting variables within a template. """
     return getattr(settings, name, "")
